@@ -85,7 +85,7 @@ class Wimby:
                     if pattern.strip() != "":
                         print(f"    {pattern}")
                         if hold_score <= 60:
-                            print(f"    HOLD: {sell_score:,.2f}%")
+                            print(f"    HOLD: {hold_score:,.2f}%")
                         elif buy_score > sell_score:
                             print(f"    BUY:  {buy_score:,.2f}%")
                         else:
